@@ -2,8 +2,14 @@
 require_once("../inc/always.php");
 dbg_error_log( "freebusy", " User agent: %s", ((isset($_SERVER['HTTP_USER_AGENT']) ? $_SERVER['HTTP_USER_AGENT'] : "Unfortunately Mulberry and Chandler don't send a 'User-agent' header with their requests :-(")) );
 dbg_log_array( "headers", '_SERVER', $_SERVER, true );
-require_once("HTTPAuthSession.php");
-$session = new HTTPAuthSession();
+if ( isset($c->public_freebusy_url) && $c->public_freebusy_url ) {
+  require_once("PublicSession.php");
+  $session = new PublicSession();
+}
+else {
+  require_once("HTTPAuthSession.php");
+  $session = new HTTPAuthSession();
+}
 
 /**
 * Submission parameters recommended by calconnect, plus some generous alternatives
