@@ -1,6 +1,6 @@
 <?php
 require_once("../inc/always.php");
-require_once("RSCDSSession.php");
+require_once("DAViCalSession.php");
 $session->LoginRequired();
 
 require_once("interactive-page.php");
@@ -17,4 +17,4 @@ post your problem in the DAViCal forums on Sourceforge itself.</p>
 
 include("page-footer.php");
 
-?>
\ No newline at end of file
+?>
