@@ -77,12 +77,33 @@ class CalDAVRequest
   */
   var $collection_type;
 
+  /**
+  * A static structure of supported privileges.
+  */
+  var $supported_privileges;
+
   /**
   * Create a new CalDAVRequest object.
   */
   function CalDAVRequest( $options = array() ) {
     global $session, $c, $debugging;
 
+    $this->supported_privileges = array(
+      'all' => array(
+        'read' => 'Read the content of a resource or collection',
+        'write' => array(
+          'bind' => 'Create a resource or collection',
+          'unbind' => 'Delete a resource or collection',
+          'write-content' => 'Write content',
+          'write-properties' => 'Write properties'
+        ),
+        'urn:ietf:params:xml:ns:caldav:read-free-busy' => 'Read the free/busy information for a calendar collection',
+        'read-acl' => 'Read ACLs for a resource or collection',
+        'write-acl' => 'Write ACLs for a resource or collection',
+        'unlock' => 'Remove a lock'
+      )
+    );
+
     $this->options = $options;
     if ( !isset($this->options['allow_by_email']) ) $this->options['allow_by_email'] = false;
     $this->principal = (object) array( 'username' => $session->username, 'user_no' => $session->user_no );
@@ -93,8 +114,9 @@ class CalDAVRequest
       /** Log the request headers */
       $lines = apache_request_headers();
       dbg_error_log( "LOG ", "***************** Request Header ****************" );
-      foreach( $lines AS $v ) {
-        dbg_error_log( "LOG headers", "-->%s", $v );
+      dbg_error_log( "LOG ", "%s %s", $_SERVER['REQUEST_METHOD'], $_SERVER['REQUEST_URI'] );
+      foreach( $lines AS $k => $v ) {
+        dbg_error_log( "LOG headers", "-->%s: %s", $k, $v );
       }
       dbg_error_log( "LOG ", "******************** Request ********************" );
       // Log the request in all it's gory detail.
@@ -185,8 +207,14 @@ class CalDAVRequest
     *  4. otherwise we query the defined relationships between users and use
     *     the minimum privileges returned from that analysis.
     */
-    $this->path = (isset($_SERVER['PATH_INFO']) ? $_SERVER['PATH_INFO'] : "");
-    if ( $this->path == null || $this->path == '' ) $this->path = '/';
+    $this->path = (isset($_SERVER['PATH_INFO']) ? $_SERVER['PATH_INFO'] : "/");
+    $this->path = rawurldecode($this->path);
+
+    /** Allow a request for .../calendar.ics to translate into the calendar URL */
+    if ( preg_match( '#^(/[^/]+/[^/]+).ics$#', $this->path, $matches ) ) {
+      $this->path = $matches[1]. '/';
+    }
+
     // dbg_error_log( "caldav", "Sanitising path '%s'", $this->path );
     $bad_chars_regex = '/[\\^\\[\\(\\\\]/';
     if ( preg_match( $bad_chars_regex, $this->path ) ) {
@@ -230,14 +258,17 @@ class CalDAVRequest
 
       $this->collection_id = $row->collection_id;
       $this->collection_path = $row->dav_name;
+      $this->collection_type = ($row->is_calendar == 't' ? 'calendar' : 'collection');
       $this->collection = $row;
+      $this->collection->type = $this->collection_type; 
     }
     else if ( preg_match( '#^((/[^/]+/)\.(in|out)/)[^/]*$#', $this->path, $matches ) ) {
       // The request is for a scheduling inbox or outbox (or something inside one) and we should auto-create it
       $displayname = $session->fullname . ($matches[3] == 'in' ? ' Inbox' : ' Outbox');
+      $this->collection_type = 'schedule-'. $matches[3]. 'box';
       $sql = <<<EOSQL
-INSERT INTO collection ( user_no, parent_container, dav_name, dav_displayname, is_calendar, created, modified )
-    VALUES( ?, ?, ?, ?, FALSE, current_timestamp, current_timestamp )
+INSERT INTO collection ( user_no, parent_container, dav_name, dav_displayname, is_calendar, created, modified, dav_etag )
+    VALUES( ?, ?, ?, ?, FALSE, current_timestamp, current_timestamp, '1' )
 EOSQL;
       $qry = new PgQuery( $sql, $session->user_no, $matches[2] , $matches[1], $displayname );
       $qry->Exec('caldav');
@@ -248,6 +279,7 @@ EOSQL;
         $this->collection_id = $row->collection_id;
         $this->collection_path = $matches[1];
         $this->collection = $row;
+        $this->collection->type = $this->collection_type; 
       }
     }
     else if ( preg_match( '#^((/[^/]+/)calendar-proxy-(read|write))/?[^/]*$#', $this->path, $matches ) ) {
@@ -261,14 +293,14 @@ EOSQL;
         header( "Content-Location: ".ConstructURL($this->path) );
       }
     }
-    else if ( preg_match( '#^/(\S+@\S+[.]\S+)/?$#', $this->path) ) {
+    else if ( $this->options['allow_by_email'] && preg_match( '#^/(\S+@\S+[.]\S+)/?$#', $this->path) ) {
       /** @TODO: we should deprecate this now that Evolution 2.27 can do scheduling extensions */
       $this->collection_id = -1;
       $this->collection_type = 'email';
       $this->collection_path = $this->path;
       $this->_is_principal = true;
     }
-    else if ( preg_match( '#^(/[^/]+)/?$#', $this->path, $matches) ) {
+    else if ( preg_match( '#^(/[^/]+)/?$#', $this->path, $matches) || preg_match( '#^(/principals/[^/]+/[^/]+)/?$#', $this->path, $matches) ) {
       $this->collection_id = -1;
       $this->collection_path = $matches[1].'/';  // Enforce trailling '/'
       $this->collection_type = 'principal';
@@ -278,6 +310,10 @@ EOSQL;
         dbg_error_log( "caldav", "Path is actually a collection - sending Content-Location header." );
         header( "Content-Location: ".ConstructURL($this->path) );
       }
+      if ( preg_match( '#^(/principals/[^/]+/[^/]+)/?$#', $this->path, $matches) ) {
+        // Force a depth of 0 on these, which are at the wrong URL.
+        $this->depth = 0;
+      }
     }
     else if ( $this->path == '/' ) {
       $this->collection_id = -1;
@@ -308,6 +344,7 @@ EOSQL;
                             'is_principal' => 'f',
                             'user_no' => 0,
                             'dav_displayname' => $c->system_name,
+                            'type' => 'root',
                             'created' => date('Ymd\THis')
                           );
     }
@@ -317,6 +354,7 @@ EOSQL;
           'is_calendar' => 'f',
           'is_principal' => 't',
           'is_proxy' => 't',
+          'type' => 'proxy',
           'proxy_type' => $this->proxy_type,
           'dav_displayname' => sprintf('Proxy %s for %s', $this->proxy_type, $this->principal->username),
           'collection_id' => 0,
@@ -370,6 +408,8 @@ EOSQL;
     $this->user_no = $session->user_no;
     $this->username = $session->username;
 
+    @dbg_error_log( "WARN", "Call to deprecated CalDAVRequest::UserFromPath()" );
+
     if ( $this->path == '/' || $this->path == '' ) {
       dbg_error_log( "caldav", "No useful path split possible" );
       return false;
@@ -377,6 +417,7 @@ EOSQL;
 
     $path_split = explode('/', $this->path );
     $this->username = $path_split[1];
+    if ( $this->username == 'principals' ) $this->username = $path_split[3];
     @dbg_error_log( "caldav", "Path split into at least /// %s /// %s /// %s", $path_split[1], $path_split[2], $path_split[3] );
     if ( isset($this->options['allow_by_email']) && preg_match( '#/(\S+@\S+[.]\S+)/?$#', $this->path, $matches) ) {
       $this->by_email = $matches[1];
@@ -406,7 +447,7 @@ EOSQL;
   *
   */
   function setPermissions() {
-    global $session;
+    global $c, $session;
 
     if ( $this->path == '/' || $this->path == '' ) {
       $this->permissions = array("read" => 'read' );
@@ -415,14 +456,31 @@ EOSQL;
     }
 
     if ( $session->AllowedTo("Admin") || $session->user_no == $this->user_no ) {
-      $this->permissions = array('all' => 'all' );
+      $this->permissions = array('all' => 'abstract' );
+      $this->permissions['urn:ietf:params:xml:ns:caldav:read-free-busy'] = 'real';
+      $this->permissions['read'] = 'real';
+      $this->permissions['write'] = 'aggregate';
+      $this->permissions['bind'] = 'real';      // PUT of new content (i.e. Create)
+      $this->permissions['unbind'] = 'real';  // DELETE
+      $this->permissions['write-content'] = 'real';        // PUT Modify
+      $this->permissions['write-properties'] = 'real';  // PROPPATCH
+      $this->permissions['lock'] = 'real';
+      $this->permissions['unlock'] = 'real';
+      $this->permissions['read-acl'] = 'real';
+      $this->permissions['read-current-user-privilege-set'] = 'real';
       dbg_error_log( "caldav", "Full permissions for %s", ( $session->user_no == $this->user_no ? "user accessing their own hierarchy" : "a systems administrator") );
       return;
     }
 
     $this->permissions = array();
 
-    if ( $this->IsPublic() ) $this->permissions['read'] = 'read';
+    if ( $this->IsPublic() ) {
+      $this->permissions['read'] = 'real';
+      $this->permissions['urn:ietf:params:xml:ns:caldav:read-free-busy'] = 'real';
+    }
+    else if ( isset($c->public_freebusy_url) && $c->public_freebusy_url ) {
+      $this->permissions['urn:ietf:params:xml:ns:caldav:read-free-busy'] = 'real';
+    }
 
     /**
     * In other cases we need to query the database for permissions
@@ -430,17 +488,36 @@ EOSQL;
     $qry = new PgQuery( "SELECT get_permissions( ?, ? ) AS perm;", $session->user_no, $this->user_no);
     if ( $qry->Exec("caldav") && $permission_result = $qry->Fetch() ) {
       $permission_result = "!".$permission_result->perm; // We prepend something to ensure we get a non-zero position.
-      if ( strpos($permission_result,"A") )
-        $this->permissions['all'] = 'all';
+      if ( strpos($permission_result,"A") ) {
+        $this->permissions['all'] = 'abstract';
+        $this->permissions['urn:ietf:params:xml:ns:caldav:read-free-busy'] = 'real';
+        $this->permissions['read'] = 'real';
+        $this->permissions['write'] = 'aggregate';
+        $this->permissions['bind'] = 'real';      // PUT of new content (i.e. Create)
+        $this->permissions['unbind'] = 'real';  // DELETE
+        $this->permissions['write-content'] = 'real';        // PUT Modify
+        $this->permissions['write-properties'] = 'real';  // PROPPATCH
+        $this->permissions['lock'] = 'real';
+        $this->permissions['unlock'] = 'real';
+        $this->permissions['read-acl'] = 'real';
+        $this->permissions['read-current-user-privilege-set'] = 'real';
+      }
       else {
-        if ( strpos($permission_result,"F") )       $this->permissions['freebusy'] = 'freebusy';
-        if ( strpos($permission_result,"R") )       $this->permissions['read'] = 'read';
-        if ( strpos($permission_result,"W") )
-          $this->permissions['write'] = 'write';
+        if ( strpos($permission_result,"F") )       $this->permissions['urn:ietf:params:xml:ns:caldav:read-free-busy'] = 'real';
+        if ( strpos($permission_result,"R") )       $this->permissions['read'] = 'real';
+        if ( strpos($permission_result,"W") ) {
+          $this->permissions['write'] = 'aggregate';
+          $this->permissions['bind'] = 'real';      // PUT of new content (i.e. Create)
+          $this->permissions['unbind'] = 'real';  // DELETE
+          $this->permissions['write-content'] = 'real';        // PUT Modify
+          $this->permissions['write-properties'] = 'real';  // PROPPATCH
+          $this->permissions['lock'] = 'real';
+          $this->permissions['unlock'] = 'real';
+        }
         else {
-          if ( strpos($permission_result,"C") )       $this->permissions['bind'] = 'bind';      // PUT of new content (i.e. Create)
-          if ( strpos($permission_result,"D") )       $this->permissions['unbind'] = 'unbind';  // DELETE
-          if ( strpos($permission_result,"M") )       $this->permissions['write-content'] = 'write-content';  // PUT Modify
+          if ( strpos($permission_result,"C") )       $this->permissions['bind'] = 'real';      // PUT of new content (i.e. Create)
+          if ( strpos($permission_result,"D") )       $this->permissions['unbind'] = 'real';  // DELETE
+          if ( strpos($permission_result,"M") )       $this->permissions['write-content'] = 'real';  // PUT Modify
         }
       }
       dbg_error_log( "caldav", "Restricted permissions for user accessing someone elses hierarchy: %s", implode( ", ", $this->permissions ) );
@@ -632,6 +709,15 @@ EOSQL;
   }
 
 
+  /**
+  * Returns true if the URL referenced by this request points at a calendar collection.
+  */
+  function IsCalendar( ) {
+    if ( !$this->IsCollection() ) return false;
+    return $this->collection->is_calendar;
+  }
+
+
   /**
   * Returns true if the URL referenced by this request points at a principal.
   */
@@ -662,6 +748,110 @@ EOSQL;
   }
 
 
+  /**
+  * Returns the array of supported privileges converted into XMLElements
+  */
+  function RenderSupportedPrivileges( $privs = null ) {
+    global $reply;
+    $privileges = array();
+    if ( $privs === null ) $privs = $this->supported_privileges;    
+    foreach( $privs AS $k => $v ) {
+      dbg_error_log( 'caldav', 'Adding privilege "%s" which is "%s".', $k, $v );
+      $privilege = new XMLElement('privilege');
+      $reply->NSElement($privilege,$k);
+      $privset = array($privilege);
+      if ( is_array($v) ) {
+        dbg_error_log( 'caldav', '"%s" is a container of sub-privileges.', $k );
+        $privset = array_merge($privset, $this->RenderSupportedPrivileges($v));
+      } 
+      else if ( $v == 'abstract' ) {
+        dbg_error_log( 'caldav', '"%s" is an abstract privilege.', $v );
+        $privset[] = new XMLElement('abstract');
+      }
+      else if ( strlen($v) > 1 ) {
+        $privset[] = new XMLElement('description', $v);
+      }
+      $privileges[] = new XMLElement('supported-privilege',$privset);
+    }
+    return $privileges;
+  }
+
+
+  /**
+  * Returns the array of privilege names converted into XMLElements
+  */
+  function RenderPrivileges($privilege_names) {
+    global $reply;
+    $privileges = array();
+    foreach( $privilege_names AS $k => $v ) {
+      dbg_error_log( 'caldav', 'Adding privilege "%s" which is "%s".', $k, $v );
+      $privilege = new XMLElement('privilege');
+      $reply->NSElement($privilege,$k);
+      $privileges[] = $privilege;
+    }
+    return $privileges;
+  }
+
+
+  /**
+  * Return general server-related properties for this URL
+  */
+  function ServerProperty( $tag, $prop, $reply = null ) {
+    global $c, $session;
+
+    if ( $reply === null ) $reply = $GLOBALS['reply'];
+
+    switch( $tag ) {
+      case 'DAV::current-user-principal':
+        $reply->DAVElement( $prop, 'current-user-principal', $this->current_user_principal_xml);
+        break;
+
+      case 'DAV::getcontentlanguage':
+        $locale = (isset($c->current_locale) ? $c->current_locale : '');
+        if ( isset($session->locale) && $session->locale != '' ) $locale = $session->locale;
+        $prop->NewElement('getcontentlanguage', $locale );
+        break;
+
+      case 'DAV::supportedlock':
+        $prop->NewElement('supportedlock',
+          new XMLElement( 'lockentry',
+            array(
+              new XMLElement('lockscope', new XMLElement('exclusive')),
+              new XMLElement('locktype',  new XMLElement('write')),
+            )
+          )
+        );
+        break;
+
+      case 'DAV::acl':
+        /**
+        * @todo This information is semantically valid but presents an incorrect picture.
+        */
+        dbg_error_log( 'caldav', 'Processing "%s" on "%s".', $tag, $this->path );
+        $principal = new XMLElement('principal');
+        $principal->NewElement('authenticated');
+        $grant = new XMLElement( 'grant', array($this->RenderPrivileges($this->permissions)) );
+        $prop->NewElement('acl', new XMLElement( 'ace', array( $principal, $grant ) ) );
+        break;
+
+      case 'DAV::current-user-privilege-set':
+        dbg_error_log( 'caldav', 'Processing "%s" on "%s".', $tag, $this->path );
+        $prop->NewElement('current-user-privilege-set', $this->RenderPrivileges($this->permissions) );
+        break;
+
+      case 'DAV::supported-privilege-set':
+        dbg_error_log( 'caldav', 'Processing "%s" on "%s".', $tag, $this->path );
+        $prop->NewElement('supported-privilege-set', $this->RenderSupportedPrivileges() );
+        break;
+
+      default:
+        dbg_error_log( 'caldav', 'Request for unsupported property "%s" of path "%s".', $tag, $this->path );
+        return false;
+    }
+    return true;
+  }
+
+
   /**
   * Are we allowed to do the requested activity
   *
@@ -676,22 +866,27 @@ EOSQL;
   * @param string $activity The activity we want to do.
   */
   function AllowedTo( $activity ) {
+    global $session;
+    dbg_error_log('session', 'Checking whether "%s" is allowed to "%s"', $session->username, $activity);
+    foreach( $this->permissions AS $k => $v ) {
+      dbg_error_log('session', 'Permissions "%s" is "%s"', $k, $v);
+    }
     if ( isset($this->permissions['all']) ) return true;
     switch( $activity ) {
       case "CALDAV:schedule-send-freebusy":
-        return isset($this->permissions['read']) || isset($this->permissions['freebusy']);
+        return isset($this->permissions['read']) || isset($this->permissions['urn:ietf:params:xml:ns:caldav:read-free-busy']);
         break;
 
       case "CALDAV:schedule-send-invite":
-        return isset($this->permissions['read']) || isset($this->permissions['freebusy']);
+        return isset($this->permissions['read']) || isset($this->permissions['urn:ietf:params:xml:ns:caldav:read-free-busy']);
         break;
 
       case "CALDAV:schedule-send-reply":
-        return isset($this->permissions['read']) || isset($this->permissions['freebusy']);
+        return isset($this->permissions['read']) || isset($this->permissions['urn:ietf:params:xml:ns:caldav:read-free-busy']);
         break;
 
       case 'freebusy':
-        return isset($this->permissions['read']) || isset($this->permissions['freebusy']);
+        return isset($this->permissions['read']) || isset($this->permissions['urn:ietf:params:xml:ns:caldav:read-free-busy']);
         break;
 
       case 'delete':
@@ -807,7 +1002,11 @@ EOSQL;
   * @return array The supported privileges.
   */
   function SupportedPrivileges() {
-    $privs = array( "all"=>1, "read"=>1, "write"=>1, "bind"=>1, "unbind"=>1, "write-content"=>1);
+    $privs = array( 'all'=>'abstract', 'read'=>'real',
+                    'write'=>'real', 'bind'=>'real',
+                    'unbind'=>'real', 'write-content'=>'real',
+                    'write-properties'=>'real',
+                    'urn:ietf:params:xml:ns:caldav:read-free-busy' => 'real');
     return $privs;
   }
 }
