@@ -32,6 +32,16 @@ $c->base_directory = preg_replace("#/[^/]*$#", "", $_SERVER['DOCUMENT_ROOT']);
 $c->stylesheets = array( $c->base_url."/davical.css" );
 $c->images      = $c->base_url . "/images";
 
+// Add a default for newly created users
+$c->template_usr = array( 'active' => true,
+                          'locale' => 'en_EN',
+                          'date_format_type' => 'E',
+                          'email_ok' => date('Y-m-d')
+                        );
+
+$c->hide_TODO = true;                      // VTODO only visible to collection owner
+$c->readonly_webdav_collections = true;    // WebDAV access is readonly
+
 // Ensure that ../inc is in our included paths as early as possible
 set_include_path( '../inc'. PATH_SEPARATOR. get_include_path());
 
@@ -51,7 +61,9 @@ if ( !isset($_SERVER['SERVER_NAME']) ) {
 /**
 * Calculate the simplest form of reference to this page, excluding the PATH_INFO following the script name.
 */
-$c->protocol_server_port_script = sprintf( "%s://%s%s%s", (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] == 'on'? 'https' : 'http'), $_SERVER['SERVER_NAME'],
+$c->protocol_server_port_script = sprintf( "%s://%s%s%s",
+                 (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] == 'on'? 'https' : 'http'),
+                 $_SERVER['SERVER_NAME'],
                  (
                    ( (!isset($_SERVER['HTTPS']) || $_SERVER['HTTPS'] != 'on') && $_SERVER['SERVER_PORT'] == 80 )
                            || (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] == 'on' && $_SERVER['SERVER_PORT'] == 443 )
@@ -70,9 +82,6 @@ init_gettext( 'davical', '../locale' );
 if ( @file_exists("/etc/davical/".$_SERVER['SERVER_NAME']."-conf.php") ) {
   include_once("/etc/davical/".$_SERVER['SERVER_NAME']."-conf.php");
 }
-else if ( @file_exists("/etc/rscds/".$_SERVER['SERVER_NAME']."-conf.php") ) {
-  include_once("/etc/rscds/".$_SERVER['SERVER_NAME']."-conf.php");
-}
 else if ( @file_exists("/etc/davical/config.php") ) {
   include_once("/etc/davical/config.php");
 }
@@ -107,15 +116,15 @@ awl_set_locale($c->default_locale);
 *
 */
 $c->code_version = 0;
-$c->version_string = '0.9.7'; // The actual version # is replaced into that during the build /release process
+$c->version_string = '0.9.7.6'; // The actual version # is replaced into that during the build /release process
 if ( isset($c->version_string) && preg_match( '/(\d+)\.(\d+)\.(\d+)(.*)/', $c->version_string, $matches) ) {
   $c->code_major = $matches[1];
   $c->code_minor = $matches[2];
   $c->code_patch = $matches[3];
   $c->code_version = (($c->code_major * 1000) + $c->code_minor).".".$c->code_patch;
+  dbg_error_log("caldav", "Version (%d.%d.%d) == %s", $c->code_major, $c->code_minor, $c->code_patch, $c->code_version);
+  header( sprintf("Server: %d.%d", $c->code_major, $c->code_minor) );
 }
-dbg_error_log("caldav", "Version (%d.%d.%d) == %s", $c->code_major, $c->code_minor, $c->code_patch, $c->code_version);
-header( sprintf("Server: %d.%d", $c->code_major, $c->code_minor) );
 
 /**
 * Force the domain name to what was in the configuration file
@@ -240,7 +249,7 @@ function getStatusMessage($status) {
 * except for any '/' characters in it.
 * @param string $partial_path  The part of the path after the script name
 */
-function ConstructURL( $partial_path ) {
+function ConstructURL( $partial_path, $force_script = false ) {
   global $c;
 
   $partial_path = rawurlencode($partial_path);
@@ -251,9 +260,14 @@ function ConstructURL( $partial_path ) {
     $c->_url_script_path = $c->protocol_server_port_script . $c->_url_script_path;
   }
 
-  $url = $c->_url_script_path . $partial_path;
+  $url = $c->_url_script_path;
+  if ( $force_script ) {
+    if ( ! preg_match( '#/caldav\.php$#', $url ) ) $url .= '/caldav.php';
+  }
+  $url .= $partial_path;
   $url = preg_replace( '#^(https?://.+)//#', '$1/', $url );  // Ensure we don't double any '/'
   $url = preg_replace('#^https?://[^/]+#', '', $url );       // Remove any protocol + hostname portion
+
   return $url;
 }
 
