@@ -25,10 +25,11 @@
 * @license   http://gnu.org/copyleft/gpl.html GNU GPL v2
 */
 
+if ( function_exists('CreateHomeCalendar') ) return(true);
+
 require_once("AWLUtilities.php");
 require_once("DataUpdate.php");
 
-
 /**
 * Create a default home calendar for the user.
 * @param string $username The username of the user we are creating relationships for.
@@ -99,8 +100,27 @@ function UpdateUserFromExternal( &$usr ) {
   }
 
   $qry = new PgQuery("SELECT * FROM usr WHERE user_no = $usr->user_no;" );
-  if ( $qry->Exec('Login',__LINE,__FILE__) && $qry->rows == 1 )
+  if ( $qry->Exec('Login',__LINE,__FILE__) && $qry->rows == 1 ) {
     $type = "UPDATE";
+    if ( $old = $qry->Fetch() ) {
+      $changes = false;
+      foreach( $usr AS $k => $v ) {
+        if ( $old->{$k} != $v ) {
+          $changes = true;
+          dbg_error_log("Login","User '%s' field '%s' changed from '%s' to '%s'", $usr->username, $k, $old->{$k}, $v );
+          break;
+        }
+      }
+      if ( !$changes ) {
+        dbg_error_log("Login","No changes to user record for '%s' - leaving as-is.", $usr->username );
+        if ( isset($usr->active) && $usr->active == 'f' ) return false;
+        return; // Normal case, if there are no changes
+      }
+      else {
+        dbg_error_log("Login","Changes to user record for '%s' - updating.", $usr->username );
+      }
+    }
+  }
   else
     $type = "INSERT";
 
@@ -125,7 +145,7 @@ function UpdateUserFromExternal( &$usr ) {
 *
 * Use this as in the following example config snippet:
 *
-* require_once('auth-functions.php');
+*  include('auth-functions.php');
 *  $c->authenticate_hook = array(
 *      'call'   => 'AuthExternalAwl',
 *      'config' => array(
@@ -170,7 +190,7 @@ EOERRMSG;
   if ( $qry->Exec('Login',__LINE,__FILE__) && $qry->rows == 1 ) {
     $usr = $qry->Fetch();
     if ( session_validate_password( $password, $usr->password ) ) {
-      UpdateUserFromExternal();
+      UpdateUserFromExternal($usr);
       return $usr;
     }
   }
