@@ -119,21 +119,9 @@ function SqlFilterFragment( $filter, $components, $property = null, $parameter =
         $finish_column = 'dtstart';  // The column we compare against the END attribute
         $start = $v->GetAttribute("start");
         $finish = $v->GetAttribute("end");
-        if ( isset($start) && isset($finish) ) {
-          $sql .= sprintf( "AND ( (%s >= %s::timestamp with time zone AND %s <= %s::timestamp with time zone) ",
-                                  $start_column, qpg($start), $finish_column, qpg($finish));
-          $sql .= sprintf( "OR (calculate_later_timestamp(%s::timestamp with time zone,%s,rrule) >= %s::timestamp with time zone ", qpg($start), $finish_column, qpg($start) );
-          $sql .= sprintf( "AND calculate_later_timestamp(%s::timestamp with time zone,%s,rrule) <= %s::timestamp with time zone ", qpg($start), $start_column, qpg($finish) );
-          $sql .= sprintf( "AND calculate_later_timestamp(%s::timestamp with time zone,%s,rrule) <= ", qpg($start), $finish_column );
-          $sql .= sprintf( " calculate_later_timestamp(%s::timestamp with time zone,%s,rrule) ) ", qpg($start), $start_column );
-          $sql .= sprintf( "OR event_has_exceptions(caldav_data.caldav_data) ) " );
-        }
-        else if ( isset($start) ) {
-          $sql .= sprintf( "AND (%s >= %s::timestamp with time zone ", $start_column, qpg($start));
-          $sql .= sprintf( "OR calculate_later_timestamp(%s::timestamp with time zone,%s,rrule) >= %s::timestamp with time zone) ", qpg($start), $start_column, qpg($start) );
-        }
-        else if ( isset( $finish ) ) {
-          $sql .= sprintf( "AND %s <= %s::timestamp with time zone ", $finish_column, qpg($finish) );
+        if ( isset($start) || isset($finish) ) {
+          $sql .= "AND (rrule_event_overlaps( dtstart, dtend, rrule, ".qpg($start).", ".qpg($finish)." ) ";
+          $sql .= sprintf( "OR event_has_exceptions(caldav_data.caldav_data) )" );
         }
         break;
 
